element_decoders: Make HEIMS element nos human-readable

element_decodersR Documentation

Make HEIMS element nos human-readable

Description

Make HEIMS element nos human-readable

Usage

rename_heims(DT)

element2name(v)

Arguments

DT

The data table with original names

v

A vector of element names.

Details

See heims_data_dict. Note that decode_heims is generally better, as it decodes the variable if a decoder is present in the dictionary.

element2name is the inverse of browse_elements: given an element like E306, it returns the name (HE_Provider_cd.)

Value

DT with the new names or the vector with the names translated.


heims documentation built on Aug. 22, 2026, 5:06 p.m.