| utilities | R Documentation |
Only included here because of the unusual nature of heims_data_dict.
AND()
OR()
never(v)
every(v)
always(v)
is.Date(v)
is.YearMonth(v)
nth_digit_of(x, n)
between(...)
or(...)
and(...)
if_else(...)
coalesce(...)
a %fin% tbl
rm_leading_0s(v)
as.integer64(v)
is.integer64(v)
force_integer(v)
ymd(...)
v |
A vector. |
x, n |
vectors |
... |
Passed to other functions |
a |
Element suspected to be in |
tbl |
A lookup table. |
nth_digit_of returns the nth digit of the number starting from the units and going up in magnitude.
nth_digit_of(503, 1) == 1
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.